==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Output/alsa/translations/alsa_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA Eklentisi</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>ALSA Çıktı Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA Çıktı Eklentisi</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA Eklentisi Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Aygıt Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Ses aygıtı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation>Karıştırıcı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation>Karıştırıcı kartı:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation>Karıştırıcı aygıtı:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation>Gelişmiş Ayarlar</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation>Ses kartı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation>Arabellek süresi (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation>Periyot süresi (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation>mmap erişimi kullan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Snd_pcm_pause işlevi</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Output/alsa/translations/alsa_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AlsaSettingsDialog</name>
    <message>
        <location filename="../alsasettingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA Eklentisi Ayarları</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Aygıt Ayarları</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="54"/>
        <source>Audio device</source>
        <translation>Ses aygıtı</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="70"/>
        <source>Mixer</source>
        <translation>Karıştırıcı</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="94"/>
        <source>Mixer card:</source>
        <translation>Karıştırıcı kartı:</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="104"/>
        <source>Mixer device:</source>
        <translation>Karıştırıcı aygıtı:</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="121"/>
        <source>Advanced Settings</source>
        <translation>Gelişmiş Ayarlar</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="142"/>
        <source>Soundcard</source>
        <translation>Ses kartı</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="148"/>
        <source>Buffer time (ms):</source>
        <translation>Arabellek süresi (ms):</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="184"/>
        <source>Period time (ms):</source>
        <translation>Periyot süresi (ms):</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="220"/>
        <source>Use mmap access</source>
        <translation>mmap erişimi kullan</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="240"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Snd_pcm_pause işlevi</translation>
    </message>
</context>
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA Eklentisi</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="55"/>
        <source>About ALSA Output Plugin</source>
        <translation>ALSA Çıktı Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA Çıktı Eklentisi</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
